jQuery(function ($) {
	// Handle the user export click action.
	jQuery('a#dlm-download-log').on('click', function (e) {
		e.preventDefault();
		start_export(this);
	});

	function start_export(el) {
		const active = jQuery('ul.dlm-insights-tab-navigation').find('li.dlm-insights-tab-navigation__element.active').attr('id');
		// Handle Overview export.
		if ('general_info' == active) {

			// Get the data from the dlmReportsInstance object.
			const dataResponse = JSON.parse(JSON.stringify(dlmReportsInstance.mostDownloaded));
			const $downloads   = [];
			// Cycle through the data and add the download object to the array.
			Object.values(dataResponse).forEach( ( download, index) => {
				// Add extra data to the download object.
				Object.assign(download, dlmReportsInstance.getDownloadByID(download.id) );
				// In case the Enhanced Metrics plugin is active, add the percentage of downloads.
				if ('undefined' !== typeof dlmEnhancedMetrics) {
					download.percent = parseFloat(parseInt(download.total) * 100 / parseInt(dlmReportsInstance.totalDownloads)).toFixed(2);
				}
				$downloads.push(download);
			});

			let data = {
				downloads: $downloads,
			};

			let xhr = new XMLHttpRequest();
			xhr.open("POST", ajaxurl + '?action=dlm_export_overview&nonce=' + dlm_ce_nonce);
			xhr.responseType = 'blob';
			xhr.setRequestHeader("Content-Type", "application/json");
			xhr.send(JSON.stringify(data));
			xhr.onload = function (e) {
				if (this.status == 200) {
					var blob = new Blob([this.response], {type: 'text/csv'});
					let a    = document.createElement("a");
					a.style  = "display: none";
					document.body.appendChild(a);
					let url    = window.URL.createObjectURL(blob);
					a.href     = url;
					a.download = 'download_overview_log.csv';
					a.click();
					window.URL.revokeObjectURL(url);
				}
			};


		}

		// Handle user reports export.
		if ('user_reports' == active) {
			// @todp: add user reports export from dlmReportsInstance object also, like above.
			const $this          = jQuery(el);
			const link           = $this.attr('href');
			let start            = dlmReportsInstance.createDateElement(new Date(dlmReportsInstance.dates.downloads.start_date));
			let end              = dlmReportsInstance.createDateElement(new Date(dlmReportsInstance.dates.downloads.end_date));
			let filters          = dlmReportsInstance.currentFilters;
			window.location.href = link + '&nonce=' + dlm_ce_nonce + '&start_date=' + start + '&end_date=' + end + '&user_filters=' + encodeURIComponent(JSON.stringify(filters));
		}
	}

	/**
	 * Display the export settings
	 */
	jQuery('li.dlm-insights-tab-navigation__element').on('click', function (e) {
		const active = jQuery(this).attr('id');
		jQuery('.dlm-export-settings__body').removeClass('current');
		jQuery('#' + active + '_settings').addClass('current');
	});

	/**
	 * Display the export settings
	 */
	jQuery('a#dlm-export-settings').on('click', function (e) {
		e.stopPropagation();
		$('.dlm-export-settings__body.current').toggleClass('dlm-export-settings__body--open');
	});

	/**
	 * Hide the export settings when clicked outside
	 */
	jQuery('html body').on('click', function (e) {
		$('.dlm-export-settings__body').removeClass('dlm-export-settings__body--open');
	});

	/**
	 * Update the export settings
	 */
	jQuery('.dlm-export-settings__body input').on('click', function (e) {
		e.stopPropagation();
		// Disable the button so that we can update the settings before we
		// can export again
		jQuery('a#dlm-download-log').attr('disabled', true);
		// Get our settings holder. Should have the class current.
		const settingsHolder = jQuery(this).parents('.dlm-csv-export-wrapper__export_settings').find( '.dlm-export-settings__body.current' );
		// Get the tab id
		const tabId = settingsHolder.attr('id');
		// Create our variables and constants
		const $checkboxes = settingsHolder.find('input:checked');

		let $data = {
			action : 'dlm_ce_update_export_settings',
			nonce  : dlm_ce_nonce,
			values : [],
			setting: tabId,
		};

		// Get all the checked values
		jQuery.each($checkboxes, function (index, value) {
			$data.values.push(value.value);
		});

		// Let's do an ajax call to update the settings
		jQuery.post(ajaxurl, $data, function (response) {
			jQuery('a#dlm-download-log').removeAttr('disabled');
		});
	});
});