<?php
/*
	Plugin Name: Download Monitor - CSV Exporter
	Plugin URI: https://www.download-monitor.com/extensions/csv-exporter/
	Description: Easily export all your downloads to a CSV file.
	Version: 4.0.11
	Author: WPChill
	Author URI: https://wpchill.com
	License: GPL v3

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

	update_option( 'dlm-csv-exporter-license' , array(
			'key'    => 'B5E0B5F8DD8689E6ACA49DD6E6E1A930',
			'email'  => 'admin@gpltimes.com',
			'status' => 'active',
			'license_status' => 'active'
		) );



class DLM_CSV_Exporter {

	const VERSION = '4.0.11';

	/**
	 * Get the plugin file
	 *
	 * @static
	 *
	 * @return String
	 */
	public static function get_plugin_file() {
		return __FILE__;
	}

	public function __construct() {
		// Register Extension.
		add_filter( 'dlm_extensions', array( $this, 'register_extension' ) );
		// Only in admin.
		if ( is_admin() ) {
			add_action( 'admin_notices', array( $this, 'admin_notices' ), 8 );
			// Add filter for compatibility, will be removed migration has been done.
			add_filter( 'dlm_disable_update_for_dlm-csv-exporter', '__return_false', 15 );
			if ( ! $this->check_functionality() ) {
				return;
			}
			// The Export Page.
			$export_page = new DLM_CE_Export_Page();
			$export_page->register_hooks();

			// Catch the export request.
			$export_manager = new DLM_CE_Export_Manager();
			add_action( 'admin_init', array( $export_manager, 'catch_export_request' ) );
			new DLM_CE_Logs_Export();
		}
	}

	/**
	 * Register this extension
	 *
	 * @param array $extensions
	 *
	 * @return array $extensions
	 */
	public function register_extension( $extensions ) {

		$extensions[] = array(
			'file'    => 'dlm-csv-exporter',
			'version' => self::VERSION,
			'name'    => 'CSV Exporter'
		);

		return $extensions;
	}

	/**
	 * Display admin notices
	 *
	 * @return void
	 */
	public function admin_notices() {

		if ( ! class_exists( 'WP_DLM' ) ) {
			?>
			<div class="error">
				<p><?php _e( 'Download Monitor - CSV Exporter requires Download Monitor to work.', 'dlm-csv-exporter' ); ?></p>
			</div>
			<?php
		}

	}

	/**
	 * Check extensions functionality
	 *
	 * @return bool
	 *
	 * @since 4.0.8
	 */
	public function check_functionality() {
		if ( class_exists( 'DLM_Admin_Helper' ) ) {
			$admin_helper = DLM_Admin_Helper::get_instance();
			if ( method_exists( $admin_helper, 'check_license_validity' ) ) {
				if ( ! $admin_helper->check_license_validity( 'dlm-csv-exporter' ) ) {
					return false;
				}
			}
		}

		return true;
	}
}

require_once dirname( __FILE__ ) . '/vendor/autoload_52.php';

function __dlm_csv_exporter() {

	define( 'DLM_CSVE_PATH', plugin_dir_path( __FILE__ ) );
	define( 'DLM_CSVE_URL', plugin_dir_url( __FILE__ ) );

	require_once __DIR__ . '/includes/Product/class-dlm-product-child.php';
	require_once __DIR__ . '/includes/class-dlm-extensions-notices.php';

	new DLM_CSV_Exporter();
}

add_action( 'plugins_loaded', '__dlm_csv_exporter', 11 );

register_activation_hook( __FILE__, 'dlm_csv_exporter_activate_plugin' );

register_deactivation_hook( __FILE__, 'dlm_csv_exporter_deactivate_plugin' );

function dlm_csv_exporter_deactivate_plugin() {
	// Deactivate extension license if exists.
	if ( class_exists( 'DLM_Extensions_Handler' ) ) {
		$extensions = DLM_Extensions_Handler::get_instance();
		$extensions->handle_extension_action( 'deactivate', array(
			'slug' => 'dlm-csv-exporter',
			'name' => 'CSV Exporter'
		) );
	}
}

function dlm_csv_exporter_activate_plugin() {

	// Activate extension license if exists.
	if ( class_exists( 'DLM_Extensions_Handler' ) ) {
		$extensions = DLM_Extensions_Handler::get_instance();
		$extensions->handle_extension_action( 'activate', array(
			'slug' => 'dlm-csv-exporter',
			'name' => 'CSV Exporter'
		) );
	}
}